@@ -1,21 +1,8 @@
-/*****************************************************************************
- * This file is part of KDevelop                                             *
- * Copyright 2011-2013 Sven Brauch <svenbrauch@googlemail.com>               *
- *                                                                           *
- * This program is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU General Public License as            *
- * published by the Free Software Foundation; either version 2 of            *
- * the License, or (at your option) any later version.                       *
- *                                                                           *
- * This program is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
- * GNU General Public License for more details.                              *
- *                                                                           *
- * You should have received a copy of the GNU General Public License         *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
- *****************************************************************************
- */
+/*
+    SPDX-FileCopyrightText: 2011-2013 Sven Brauch <svenbrauch@googlemail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "helpers.h"
 
@@ -43,11 +30,8 @@
 #include <interfaces/icore.h>
 #include <interfaces/ilanguagecontroller.h>
 #include <interfaces/idocumentcontroller.h>
-#include <interfaces/ipartcontroller.h>
 #include <util/path.h>
 
-#include <shell/partcontroller.h>
-
 #include <KTextEditor/View>
 #include <KConfigGroup>
 
@@ -58,6 +42,12 @@
 #include "kdevpythonversion.h"
 #include "expressionvisitor.h"
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+#define SkipEmptyParts Qt::SkipEmptyParts
+#else
+#define SkipEmptyParts QString::SkipEmptyParts
+#endif
+
 using namespace KDevelop;
 
 namespace Python {
@@ -95,7 +85,7 @@ void Helper::scheduleDependency(const IndexedString& dependency, int betterThanP
 IndexedDeclaration Helper::declarationUnderCursor(bool allowUse)
 {
     KDevelop::IDocument* doc = ICore::self()->documentController()->activeDocument();
-    const auto view = static_cast<KDevelop::PartController*>(ICore::self()->partController())->activeView();
+    const auto view = ICore::self()->documentController()->activeTextDocumentView();
     if ( doc && doc->textDocument() && view ) {
         DUChainReadLocker lock;
         const auto cursor = view->cursorPosition();
@@ -124,7 +114,7 @@ Declaration* Helper::accessAttribute(const AbstractType::Ptr accessed,
             return type && type->whichType() == AbstractType::TypeStructure;
         },
         [](AbstractType::Ptr toMap) {
-            return StructureType::Ptr::staticCast(Helper::resolveAliasType(toMap));
+            return Helper::resolveAliasType(toMap).staticCast<StructureType>();
         }
     );
     auto docFileContext = Helper::getDocumentationFileContext();
@@ -153,7 +143,7 @@ AbstractType::Ptr Helper::resolveAliasType(const AbstractType::Ptr eventualAlias
 AbstractType::Ptr Helper::extractTypeHints(AbstractType::Ptr type)
 {
     return Helper::foldTypes(Helper::filterType<AbstractType>(type, [](AbstractType::Ptr t) -> bool {
-        auto hint = t.cast<HintedType>();
+        auto hint = t.dynamicCast<HintedType>();
         return !hint || hint->isValid();
     }));
 }
@@ -323,8 +313,8 @@ static QString _relativePath(const QString &base_dir, const QString &path)
    if (_base_dir[_base_dir.length()-1] != QLatin1Char('/'))
       _base_dir.append(QLatin1Char('/') );
 
-   const QStringList list1 = _base_dir.split(QLatin1Char('/'), QString::SkipEmptyParts);
-   const QStringList list2 = _path.split(QLatin1Char('/'), QString::SkipEmptyParts);
+   const QStringList list1 = _base_dir.split(QLatin1Char('/'), SkipEmptyParts);
+   const QStringList list2 = _path.split(QLatin1Char('/'), SkipEmptyParts);
 
    // Find where they meet
    int level = 0;
@@ -480,7 +470,7 @@ QVector<QUrl> Helper::getSearchPaths(const QUrl& workingOnDocument)
         QString pythonpath = QString::fromUtf8(python.readAllStandardOutput());
 
         if ( ! pythonpath.isEmpty() ) {
-            const auto paths = pythonpath.split("$|$", QString::SkipEmptyParts);
+            const auto paths = pythonpath.split("$|$", SkipEmptyParts);
             foreach ( const QString& path, paths ) {
                 cachedForProject.append(QUrl::fromLocalFile(path));
             }
@@ -525,23 +515,23 @@ AbstractType::Ptr Helper::contentOfIterable(const AbstractType::Ptr iterable, co
     AbstractType::Ptr content(new IntegralType(IntegralType::TypeMixed));
 
     for ( const auto& type: types ) {
-        if ( auto map = type.cast<MapType>() ) {
+        if ( auto map = type.dynamicCast<MapType>() ) {
             // Iterating over dicts gets keys, not values
             content = mergeTypes(content, map->keyType().abstractType());
             continue;
         }
-        else if ( auto list = type.cast<ListType>() ) {
+        else if ( auto list = type.dynamicCast<ListType>() ) {
             content = mergeTypes(content, list->contentType().abstractType());
             continue;
         }
-        else if ( auto indexed = type.cast<IndexedContainer>() ) {
+        else if ( auto indexed = type.dynamicCast<IndexedContainer>() ) {
             content = mergeTypes(content, indexed->asUnsureType());
             continue;
         }
         DUChainReadLocker lock;
         // Content of an iterable object is iterable.__iter__().__next__().
         if ( auto iterFunc = dynamic_cast<FunctionDeclaration*>(accessAttribute(type, iterId, topContext)) ) {
-            if ( auto iterator = iterFunc->type<FunctionType>()->returnType().cast<StructureType>() ) {
+            if ( auto iterator = iterFunc->type<FunctionType>()->returnType().dynamicCast<StructureType>() ) {
                 if ( auto nextFunc = dynamic_cast<FunctionDeclaration*>(accessAttribute(iterator, nextId, topContext)) ) {
                     content = mergeTypes(content, nextFunc->type<FunctionType>()->returnType());
                 }
