@@ -433,6 +433,12 @@ void PyDUChainTest::testCrashes_data() {
 #endif
     QTest::newRow("definition_in_baseclass_1") << "class Foo(lambda x: 1): pass";
     QTest::newRow("definition_in_baseclass_2") << "class Foo([x for x in (1, 2)]): pass";
+#if PYTHON_VERSION >= QT_VERSION_CHECK(3, 10, 0)
+    QTest::newRow("match") << "match x.split():\n case [a, b]: pass";
+#endif
+#if PYTHON_VERSION >= QT_VERSION_CHECK(3, 11, 0)
+    QTest::newRow("except_star") << "try: pass\nexcept* (IndexError, ValueError): pass";
+#endif
 }
 
 void PyDUChainTest::testClassVariables()
@@ -1641,7 +1647,7 @@ void PyDUChainTest::testContainerTypes()
     QVERIFY(decls.length() > 0);
     QVERIFY(decls.first()->abstractType());
     if ( ! use_type ) {
-        auto type = ListType::Ptr::dynamicCast(decls.first()->abstractType());
+        auto type = decls.first()->abstractType().dynamicCast<ListType>();
         QVERIFY(type);
         QVERIFY(type->contentType());
         QCOMPARE(type->contentType().abstractType()->toString(), contenttype);
@@ -1798,6 +1804,10 @@ void PyDUChainTest::testVariableCreation_data()
 #if PYTHON_VERSION >= QT_VERSION_CHECK(3, 8, 0)
     QTest::newRow("assignment_expr") << "a = (b := 10)" << QStringList{"a", "b"} << QStringList{"int", "int"};
 #endif
+#if PYTHON_VERSION >= QT_VERSION_CHECK(3, 10, 0)
+    QTest::newRow("match") << "match 'x'.split():\n case [a, b]: pass" << QStringList{"a", "b"} << QStringList{"str", "str"};
+    QTest::newRow("match_as") << "match 'x'.split():\n case [a, b] as w: pass" << QStringList{"w"} << QStringList{"list of str"};
+#endif
 }
 
 void PyDUChainTest::testCleanupMultiplePasses()
